[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/xlextract.svg)](https://img.shields.io/pypi/pyversions/xlextract)
[![PyPI](https://img.shields.io/pypi/v/xlextract.svg)](https://pypi.python.org/pypi/xlextract)
[![Downloads](https://static.pepy.tech/badge/xlextract)](https://static.pepy.tech/badge/xlextract)
[![Code Style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)

XLExtract
=========

An abstraction layer for quickly pulling data out of Microsoft Excel Spreadsheets.

The project is currently powered by the [openpyxl](https://pypi.org/project/openpyxl/) library but you don't need to know anything about the underlying library and it could change in the future.

## Installation
xlextract can be installed via poetry with: 'poetry add xlextract'  
or via pip with: 'pip install xlextract'